@@ -8,13 +8,13 @@ def cli():
     pass
 
 
-
 @click.command(help="Launch a LiteNet Server")
 @click.option("-h", "--host", required=True, type=str, help="The ip to run the server on. (Must have access to it.)")
 @click.option("-p", "--port", default=5050, type=int, help="The port to run the server on. (Must be a valid port.)")
 @click.option("--header", "header", default=64, type=int, help="The size of the server message header.")
-def server(host, port, header):
-    litenet = LiteNetServer(host, port, header=header)
+@click.option("-d", "--debug", is_flag=True, help="Enters debug mode.")
+def server(host, port, header, debug):
+    litenet = LiteNetServer(host, port, header, debug=debug)
     litenet.start()
 
 
@@ -22,8 +22,9 @@ def server(host, port, header):
 @click.option("-h", "--host", required=True, type=str, help="The ip the server's running on. (Must have access to it.)")
 @click.option("-p", "--port", default=5050, type=int, help="The port the server's running on. (Must be a valid port.)")
 @click.option("--header", "header", default=64, type=int, help="The size of the server message header. (Must match the server's.)")
-def client(host, port, header):
-    client = LiteNetClient(host, port, header)
+@click.option("-d", "--debug", is_flag=True, help="Enters debug mode.")
+def client(host, port, header, debug):
+    client = LiteNetClient(host, port, header, debug=debug)
     client.start()
 
 
