@@ -5,7 +5,7 @@ from litenet.utils import to_liteaddr
 
 
 class LiteNetServer:
-    def __init__(self, ip, port=5050, header=64, encoding="utf-8"):
+    def __init__(self, ip, port=5050, header=64, encoding="utf-8", debug=False):
         self.ip, self.port = ip, port
 
         self.header, self.encoding = header, encoding
@@ -16,15 +16,18 @@ class LiteNetServer:
 
         self.server = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 
+        self.debug = debug
+
         self._stopped = False
 
     def start(self):
         threading.Thread(target=self._start).start()
 
     def _start(self):
-        self.server.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
         self.server.bind((self.ip, self.port))
+        self.server.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
         self.server.listen()
+
         print(f"LiteNet Server Listening on {self.ip}:{self.port}")
 
         while not self._stopped:
@@ -33,6 +36,9 @@ class LiteNetServer:
             thread.start()
             print(f"[NEW CONNECTION] {addr}")
 
+            if self.debug:
+                print(self.active_client_count)
+                print(self.clients, "\n")
         self.server.close()
 
     def handle_client(self, conn, addr):
@@ -41,31 +47,31 @@ class LiteNetServer:
             "connection": conn,
             "alive": True
         }
-        print(self.clients)
 
         while self.clients[addr]["alive"]:
-            msg_length = self.server.recv(self.header)
+            msg_length = self.clients[addr]["connection"].recv(self.header)
             if msg_length:
                 msg_length = int(msg_length.decode(self.encoding))
 
-                msg = self.server.recv(msg_length).decode(self.encoding)
+                msg = self.clients[addr]["connection"].recv(msg_length).decode(self.encoding)
 
                 if msg == self._close_msg:
                     break
 
-                print(addr, ">", msg)
+                print(addr[0] + ":" + str(addr[1]), ">>", msg)
 
-                msg = str(f"{addr} > {msg}")
+                msg = str(f"{to_liteaddr(addr[0]) + ':' + str(addr[1])} >> {msg}")
 
                 for client in self.clients.keys():
                     if client != addr:
-                        self.clients.get(client).get("connection").send(
-                            msg.encode(self.encoding) + b" " * (self.header - len(msg.encode(self.encoding)))
-                        )
+                        if self.clients[client]["active"]:
+                            self.clients.get(client)["connection"].send(
+                                msg.encode(self.encoding) + b" " * (self.header - len(msg.encode(self.encoding)))
+                            )
 
-                        self.clients.get(client).get("connection").send(
-                            msg.encode(self.encoding)
-                        )
+                            self.clients.get(client)["connection"].send(
+                                msg.encode(self.encoding)
+                            )
 
         conn.close()
         self.close_client(addr)
